package de.intevation.flys.client.server;

import java.util.ArrayList;

import de.intevation.flys.client.shared.exceptions.ServerException;
import de.intevation.flys.client.shared.model.Artifact;
import de.intevation.flys.client.shared.model.Collection;
import de.intevation.flys.client.shared.model.Recommendation;

import de.intevation.flys.client.client.services.LoadArtifactService;

/**
 * This service creates a new Artifact based on a given Recommendation and puts
 * this new artifact into a specified Collection.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class LoadArtifactServiceImpl
extends      ArtifactServiceImpl
implements   LoadArtifactService
{
    public static final String ERROR_LOAD_ARTIFACT = "error_load_artifact";

    public Artifact load(
        Collection     parent,
        Recommendation recom,
        String         factory,
        String         url,
        String         locale
    )
    throws ServerException {
        System.out.println(
            "LoadArtifactServiceImpl.load: " + recom.getMasterArtifact());

        // 1) Clone the Artifact specified in >>recom<<
        Artifact clone = ArtifactHelper.createArtifact(
            url, locale, factory, recom);

        if (clone != null) {
            System.out.println("Successfully create Artifact Clone. Add now!");
            Collection c = CollectionHelper.addArtifact(
                parent, clone, url, locale);

            if (c != null) {
                System.out.println("Successfully added Clone to Collection.");

                return clone;
            }
        }

        throw new ServerException(ERROR_LOAD_ARTIFACT);
    }

    public Artifact[] loadMany(
        Collection     parent,
        Recommendation[] recoms,
        String         factory,
        String         url,
        String         locale
    )
    throws ServerException {
        System.out.println(
            "LoadArtifactServiceImpl.loadMany: " + recoms[0].getMasterArtifact());
        ArrayList<Artifact> artifacts = new ArrayList<Artifact>();

        // 1) Clone the Artifacts specified in >>recom<<
        for (Recommendation recom : recoms) {
            Artifact clone = ArtifactHelper.createArtifact(
                url, locale, factory, recom);
    
            if (clone != null) {
                System.out.println("Successfully create Artifact Clone. Add now!");
                Collection c = CollectionHelper.addArtifact(
                    parent, clone, url, locale);
    
                if (c != null) {
                    System.out.println("Successfully added Clone to Collection.");
    
                    artifacts.add(clone);
                }
            }
        }
        return artifacts.toArray(new Artifact[artifacts.size()]);

        //throw new ServerException(ERROR_LOAD_ARTIFACT);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
